import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_devices/analytics_devices_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/realtime_device_changes/realtime_device_changes_bloc.dart';
import 'package:syncrow_web/pages/analytics/params/get_analytics_devices_param.dart';

abstract final class FetchAirQualityDataHelper {
  const FetchAirQualityDataHelper._();

  static void loadAirQualityData(
    BuildContext context, {
    required String communityUuid,
    required String spaceUuid,
  }) {
    loadAnalyticsDevices(
      context,
      communityUuid: communityUuid,
      spaceUuid: spaceUuid,
    );
  }

  static void clearAllData(BuildContext context) {
    context.read<AnalyticsDevicesBloc>().add(
          const ClearAnalyticsDeviceEvent(),
        );
    context.read<RealtimeDeviceChangesBloc>().add(
          const RealtimeDeviceChangesClosed(),
        );
  }

  static void loadAnalyticsDevices(
    BuildContext context, {
    required String communityUuid,
    required String spaceUuid,
  }) {
    context.read<AnalyticsDevicesBloc>().add(
          LoadAnalyticsDevicesEvent(
            param: GetAnalyticsDevicesParam(
              communityUuid: communityUuid,
              spaceUuid: spaceUuid,
              deviceTypes: ['AQI'],
              requestType: AnalyticsDeviceRequestType.energyManagement,
            ),
            onSuccess: (device) {
              context.read<RealtimeDeviceChangesBloc>()
                ..add(const RealtimeDeviceChangesClosed())
                ..add(RealtimeDeviceChangesStarted(device.uuid));
            },
          ),
        );
  }
}
